Function insert_nullifiers
Source pub fn insert_nullifiers<'a, 'b, 'c: 'info, 'info, A: InvokeAccounts<'info> + SignerAccounts<'info> + Bumps>(
inputs: &'a InstructionDataInvoke,
ctx: &'a Context<'a, 'b, 'c, 'info, A>,
nullifiers: &'a [[u8; 32]],
invoking_program: &Option<Pubkey>,
) -> Result<()>
- Checks that the nullifier queue account is associated with a state Merkle tree account.
- Checks that if nullifier queue has delegate it invoking_program is delegate.
- Inserts nullifiers into the queue.